<?php
function magento_api_service() {
	return array(

	array(
		'#method' => 'magento_api.productSaveEventHandler',
		'#callback' => 'magento_api_productSaveEventHandler',
		'#args' => array(array(
				'#name' => 'productId',
				'#type' => 'string',
				'#optional' => false,
				'#description' => 'Magento Product Id')),
		'#return' => 'boolean',
		'#help' => t('Handle Magento product save event')),
	array(
		'#method' => 'magento_api.productDeleteEventHandler',
		'#callback' => 'magento_api_productDeleteEventHandler',
		'#args' => array(array(
				'#name' => 'productId',
				'#type' => 'string',
				'#optional' => false,
				'#description' => 'Magento Product Id')	),
		'#return' => 'boolean',
		'#help' => t('Handle Magento product delete event')),
	array(
		'#method' => 'magento_api.productStatusUpdateEventHandler',
		'#callback' => 'magento_api_productStatusUpdateEventHandler',
		'#args' => array(array(
				'#name' => 'productId',
				'#type' => 'string',
				'#optional' => false,
				'#description' => 'Magento Product Id')),
		'#return' => 'boolean',
		'#help' => t('Handle Magento product status update event')),
	array(
		'#method' => 'magento_api.catalogCategorySaveEventHandler',
		'#callback' => 'magento_api_catalogCategorySaveEventHandler',
		'#args' => array(array(
				'#name' => 'tree',
				'#type' => 'array',
				'#optional' => false,
				'#description' => 'Magento Catalog Category tree')),
		'#return' => 'boolean',
		'#help' => t('Handle Magento catalog category save event')),
	array(
		'#method' => 'magento_api.catalogCategoryDeleteEventHandler',
		'#callback' => 'magento_api_catalogCategoryDeleteEventHandler',
		'#args' => array(array(
				'#name' => 'tree',
				'#type' => 'array',
				'#optional' => false,
				'#description' => 'Magento Catalog Category tree')),
		'#return' => 'boolean',
		'#help' => t('Handle Magento catalog category delete event')),
	array(
		'#method' => 'magento_api.catalogRuleApplyAfterEventHandler',
		'#callback' => 'magento_api_catalogRuleApplyAfterEventHandler',
		'#args' => array(),
		'#return' => 'boolean',
		'#help' => t('Handle Magento catalog rule after apply event')),
	// 
	);
}

/**
 * Handle Magento product save event
 *
 * @param string $productId
 * @return boolean
 */
function magento_api_productSaveEventHandler($productId) {
	try {
		if (variable_get('magento_api_log', 0)) watchdog('magento_api', 'Drupal function = %drupal_function, Magento event = %event, Arguments = %args', array('%drupal_function' => 'magento_api_productSaveEventHandler', '%event' => 'catalog_product_save', '%args' => serialize(array($productId))), WATCHDOG_NOTICE, $link = NULL);
		module_invoke_all('magento_event', 'catalog_product_save', $productId);
	}
	catch (Exception $ex)
	{
		return services_error(t('Drupal event handler error: ').$ex->getMessage());
	}
	return TRUE;
}

/**
 * Handle Magento product delete event
 *
 * @param string $productId
 * @return boolean
 */
function magento_api_productDeleteEventHandler($productId) {
	try {
		if (variable_get('magento_api_log', 0)) watchdog('magento_api', 'Drupal function = %drupal_function, Magento event = %event, Arguments = %args', array('%drupal_function' => 'magento_api_productDeleteEventHandler', '%event' => 'catalog_product_delete', '%args' => serialize(array($productId))), WATCHDOG_NOTICE, $link = NULL);
		module_invoke_all('magento_event', 'catalog_product_delete', $productId);
	}
	catch (Exception $ex)
	{
		return services_error(t('Drupal event handler error: ').$ex->getMessage());
	}
	return TRUE;
}

/**
 * Handle Magento product status update event
 *
 * @param string $productId
 * @return boolean
 */
function magento_api_productStatusUpdateEventHandler($productId) {
	try {
		if (variable_get('magento_api_log', 0)) watchdog('magento_api', 'Drupal function = %drupal_function, Magento event = %event, Arguments = %args', array('%drupal_function' => 'magento_api_productStatusUpdateEventHandler', '%event' => 'product_status_update', '%args' => serialize(array($productId))), WATCHDOG_NOTICE, $link = NULL);
		module_invoke_all('magento_event', 'product_status_update', $productId);
	}
	catch (Exception $ex)
	{
		return services_error(t('Drupal event handler error: ').$ex->getMessage());
	}
	return TRUE;
}

/**
 * Handle Magento catalog category save event
 *
 * @param array $tree
 * @return boolean
 */
function magento_api_catalogCategorySaveEventHandler($tree) {
	try {
		if (variable_get('magento_api_log', 0)) watchdog('magento_api', 'Drupal function = %drupal_function, Magento event = %event, Arguments = %args', array('%drupal_function' => 'magento_api_catalogCategorySaveEventHandler', '%event' => 'catalog_category_save', '%args' => serialize(array($tree))), WATCHDOG_NOTICE, $link = NULL);
		module_invoke_all('magento_event', 'catalog_category_save', $tree);
	}
	catch (Exception $ex)
	{
		return services_error(t('Drupal event handler error: ').$ex->getMessage());
	}
	return TRUE;
}

/**
 * Handle Magento catalog category delete event
 *
 * @param array $tree
 * @return boolean
 */
function magento_api_catalogCategoryDeleteEventHandler($tree) {
	try {
		if (variable_get('magento_api_log', 0)) watchdog('magento_api', 'Drupal function = %drupal_function, Magento event = %event, Arguments = %args', array('%drupal_function' => 'magento_api_catalogCategoryDeleteEventHandler', '%event' => 'catalog_category_delete', '%args' => serialize(array($tree))), WATCHDOG_NOTICE, $link = NULL);
		module_invoke_all('magento_event', 'catalog_category_delete', $tree);
	}
	catch (Exception $ex)
	{
		return services_error(t('Drupal event handler error: ').$ex->getMessage());
	}
	return TRUE;
}

/**
 * Handle Magento catalog rule after apply event
 *
 * @return boolean
 */
function magento_api_catalogRuleApplyAfterEventHandler() {
	try {
		if (variable_get('magento_api_log', 0)) watchdog('magento_api', 'Drupal function = %drupal_function, Magento event = %event, Arguments = %args',
			 array('%drupal_function' => 'magento_api_catalogRuleApplyAfterEventHandler', '%event' => 'catalog_rule_apply', '%args' => serialize(array(NULL))), WATCHDOG_NOTICE, $link = NULL);
		module_invoke_all('magento_event', 'catalog_rule_apply', NULL);
	}
	catch (Exception $ex)
	{
		return services_error(t('Drupal event handler error: ').$ex->getMessage());
	}
	return TRUE;
}

